==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/Performance/src/com/clustercontrol/performance/monitor/action/DeletePerformance.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 */

package com.clustercontrol.performance.monitor.action;

import java.rmi.RemoteException;

import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.naming.NamingException;
import javax.transaction.HeuristicMixedException;
import javax.transaction.HeuristicRollbackException;
import javax.transaction.InvalidTransactionException;
import javax.transaction.NotSupportedException;
import javax.transaction.RollbackException;
import javax.transaction.SystemException;

import org.quartz.SchedulerException;


import com.clustercontrol.performance.monitor.util.EjbConnectionManager;
import com.clustercontrol.performanceMGR.monitor.ejb.session.MonitorPerfController;

/**
 * ꥽ƻ륯饹Ǥ
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class DeletePerformance {

    /**
     * ꥽ƻޤ
     * 
     * @param monitorId ִƻID
     * @return 硢true
     */
    public boolean delete(String monitorId) {
    	
    	MonitorPerfController ctr = EjbConnectionManager.getConnectionManager().getMonitorPerfController();

        boolean result = false;
        try {
        	result = ctr.deletePerformance(monitorId);
        	return result;
        
        } catch (FinderException e) {
        } catch (RemoveException e) {
        } catch (SchedulerException e) {
        } catch (NamingException e) {
        } catch (NotSupportedException e) {
        } catch (HeuristicMixedException e) {
        } catch (HeuristicRollbackException e) {
        } catch (RollbackException e) {
        } catch (InvalidTransactionException e) {
        } catch (IllegalStateException e) {
        } catch (SystemException e) {
        } catch (RemoteException e) {
        }
        return false;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/Performance/src/com/clustercontrol/performance/monitor/action/DeletePerformance.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 */

package com.clustercontrol.performance.monitor.action;

import java.rmi.RemoteException;

import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.naming.NamingException;
import javax.transaction.HeuristicMixedException;
import javax.transaction.HeuristicRollbackException;
import javax.transaction.InvalidTransactionException;
import javax.transaction.NotSupportedException;
import javax.transaction.RollbackException;
import javax.transaction.SystemException;

import org.quartz.SchedulerException;


import com.clustercontrol.performance.monitor.util.EjbConnectionManager;
import com.clustercontrol.performanceMGR.monitor.ejb.session.MonitorPerfController;

/**
 * リソース監視情報を削除するクラスです。
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class DeletePerformance {

    /**
     * リソース監視情報を削除します。
     * 
     * @param monitorId 状態監視ID
     * @return 削除に成功した場合、true
     */
    public boolean delete(String monitorId) {
    	
    	MonitorPerfController ctr = EjbConnectionManager.getConnectionManager().getMonitorPerfController();

        boolean result = false;
        try {
        	result = ctr.deletePerformance(monitorId);
        	return result;
        
        } catch (FinderException e) {
        } catch (RemoveException e) {
        } catch (SchedulerException e) {
        } catch (NamingException e) {
        } catch (NotSupportedException e) {
        } catch (HeuristicMixedException e) {
        } catch (HeuristicRollbackException e) {
        } catch (RollbackException e) {
        } catch (InvalidTransactionException e) {
        } catch (IllegalStateException e) {
        } catch (SystemException e) {
        } catch (RemoteException e) {
        }
        return false;
    }
}
